<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>DeselectLayer</name>
    <message>
        <location filename="../DeselectLayerInit.js" line="+2"/>
        <source>&amp;Deselect Layer</source>
        <translation>&amp;Odznacz warstwę</translation>
    </message>
</context>
</TS>
